const STAGE_CONFIG = 'PRODUCTION';


function insertUmami() {
	const script = document.createElement('script');
	script.async = true;
	script.src = 'https://gaig-analytics.netlify.app/script.js';
	const umamiCode = '822233d5-9d21-4057-90f2-402e01675e47';
	script.setAttribute('data-website-id', umamiCode);

	try {
		document.body.appendChild(script);
	} catch (error) {
		console.log(error);
	}
}

let offeringOptions = {};
let channelUrl;

if (typeof window !== 'undefined') {
	channelUrl = window.location.href;
}

function waitForOptions() {
	const checkInterval = setInterval(() => {
		if (window?.options) {
			// console.log('options is now available', options);
			offeringOptions = options;
			// console.log('offeringOptions', offeringOptions);
			clearInterval(checkInterval); // Stop checking
		}
	}, 100); // Check every 100 milliseconds
}

try {
	document.addEventListener('DOMContentLoaded', () => {
		if (STAGE_CONFIG == 'PRODUCTION') {
			insertUmami();
		}
		waitForOptions();

	});
} catch (error) {
	console.log(error);
}

const formatPremiumForGA = (premium) => {
	const formattedPremium = parseFloat(premium.replace('$', '')).toFixed(2);
	return formattedPremium;
};

const config = {
	userEvents(e) {
		//
		if (STAGE_CONFIG != 'PRODUCTION') console.log(e);
		//
		const { data } = e;
		const { eventType } = e;
		//
		let attributionId = null
		if (typeof window?.options?.data?.policy?.meta?.attributionId !== 'undefined' && window?.options?.data?.policy?.meta?.attributionId !== null) {
			attributionId = window?.options?.data?.policy?.meta?.attributionId
		}
		if (STAGE_CONFIG != 'PRODUCTION') console.log('attributionID from userEvents', attributionId)

		const dataToSend = {
			...data,
			event_category: 'user_event',
			attributionId: attributionId
		};
		if (STAGE_CONFIG == 'PRODUCTION') {
			if (eventType === 'onViewChange') {
				//
				umami.track(e.eventType, { viewScreen: e.data.viewId, ion: offeringOptions?.ion, channelUrl, attributionId });
				//
				gtag('event', 'screen_view', {
					...dataToSend,
					screen_name: dataToSend.viewId,
					app_name: 'Season Interruption Offer Element',
				});
				//
				switch (dataToSend.viewId) {
					case 'offerView':
						break;
					case 'knockoutStateView':
						break;
					case 'insuredInfoView':
						break;
					case 'insuredSportSelectionView':
						break;
					case 'insuredIndividualSportSelection':
						break;
					case 'policyDatesView':
						break;
					case 'customerInfoView':
						break;
					case 'quickOfferView':
						break;
					case 'summary':
						break;
					case 'checkout':
						break;
					case 'thanks':
						break;
					case 'quote-error-view':
						break;
				}
				return;
			}
			//
			if (eventType === 'onQuote') {

				umami.track(e.eventType, { ion: offeringOptions?.ion, channelUrl, attributionId });

				console.log('add to cart fired', data);
				//
				gtag('event', 'add_to_cart', {
					currency: 'USD',
					value: data.pricing,
					items: [{
						item_id: 'SIC',
						// item_name: "POMI",
						affiliation: 'FLD',
						item_brand: 'FLD',
						// item_list_id: "POMI",
						// location_id: "POMI",
						price: data.pricing,
						quantity: 1
					}],
					attributionId: attributionId
				});
				//
				return;
			}
			//
			// built in GA event
			if (eventType === 'onCheckout' && data.checkoutStatus === 'start') {
				umami.track(e.eventType, {
					checkoutStatus: e.data.checkoutStatus, orderID: e.data.orderID, ion: offeringOptions?.ion, channelUrl, attributionId
				});
				//
				gtag('event', 'add_payment_info', {
					currency: 'USD',
					value: formatPremiumForGA(data.premium),
					payment_type: 'Credit Card',
					items: [{
						item_id: 'SIC',
						// item_name: "POMI",
						affiliation: 'FLD',
						item_brand: 'FLD',
						// item_list_id: "POMI",
						// location_id: "POMI",
						price: formatPremiumForGA(data.premium),
						quantity: 1
					}],
					attributionId: attributionId
				});
				gtag('event', 'begin_checkout', {
					...dataToSend,
					currency: 'USD',
					value: formatPremiumForGA(data.premium),
					attributionId: attributionId
				});
				return;
			}
			// built in GA event
			if (eventType === 'onCheckout' && data.checkoutStatus === 'success') {
				//
				umami.track(e.eventType, {
					checkoutStatus: e.data.checkoutStatus, orderID: e.data.orderID, ion: offeringOptions?.ion, channelUrl, attributionId
				});
				gtag('event', 'purchase', {
					transaction_id: dataToSend.orderID,
					value: formatPremiumForGA(data.premium),
					currency: 'USD',
					items: [{
						item_id: 'SIC',
						// item_name: "POMI",
						affiliation: 'FLD',
						item_brand: 'FLD',
						// item_list_id: "POMI",
						// location_id: "POMI",
						price: formatPremiumForGA(data.premium),
						quantity: 1
					}],
					attributionId: attributionId
				});
				//
				return;
			}
			//
			if (eventType === 'onCheckout' && data.checkoutStatus === 'error') {
				umami.track(e.eventType, {
					checkoutStatus: e.data.checkoutStatus, orderID: e.data.orderID, ion: offeringOptions?.ion, channelUrl, attributionId
				});

				gtag('event', 'failed_checkout', {
					...dataToSend,
					currency: 'USD',
					value: formatPremiumForGA(data.premium),
					error_message: data.checkoutError,
					attributionId: attributionId
				});
				return;
			}
			//
			if (eventType === 'onValidationError') {
				umami.track(e.eventType, {
					elementId: e.data.elementId, validationError: e.data.validationError, ion: offeringOptions?.ion, channelUrl, attributionId
				});
				gtag('event', 'validation_error', dataToSend);
				return;
			}
			if (eventType === 'onExternalLink') {
				umami.track(e.eventType, { externalLinkUrl: e.data.externalLinkUrl, ion: offeringOptions?.ion, channelUrl, attributionId });
				gtag('event', 'external_link_click', dataToSend);
				return;
			}
			if (eventType === 'onCheckboxSelection') {
				umami.track(e.eventType, {
					elementId: e.data.elementId, checked: e.data.checked, value: e.data.value, ion: offeringOptions?.ion, channelUrl, attributionId
				});
				gtag('event', 'checkbox_selection', dataToSend);
				return;
			}
			if (eventType === 'onRadioSelection') {
				umami.track(e.eventType, {
					elementId: e.data.elementId, value: e.data.value, ion: offeringOptions?.ion, channelUrl, attributionId
				});
				gtag('event', 'radio_selection', dataToSend);
				return;
			}
			// DEFAULT
			gtag('event', eventType, dataToSend);
		}
	},
	pomiUserEvents(e) {
		//
		if (STAGE_CONFIG != 'PRODUCTION') console.log(e);
		//
		let attributionId = null
		if (typeof window?.options?.data?.policy?.meta?.attributionId !== 'undefined' && window?.options?.data?.policy?.meta?.attributionId !== null) {
			attributionId = window?.options?.data?.policy?.meta?.attributionId
		}
		if (STAGE_CONFIG != 'PRODUCTION') console.log('attributionID from userEvents', attributionId)
		const { data } = e;
		const { eventType } = e;
		//
		const dataToSend = {
			...data,
			event_category: 'user_event',
			attributionId: attributionId
		};
		//
		if (STAGE_CONFIG == 'PRODUCTION') {
			if (eventType === 'onViewChange') {
				umami.track(e.eventType, { viewScreen: e.data.viewId, ion: offeringOptions?.ion, channelUrl, attributionId });
				//
				gtag('event', 'screen_view', {
					...dataToSend,
					screen_name: dataToSend.viewId,
					app_name: 'Pomi Season Interruption Offer Element',
				});
				//
				switch (dataToSend.viewId) {
					case 'offerView':
						break;
					case 'knockoutStateView':
						break;
					case 'insuredInfoView':
						fbq('track', 'ViewContent');
						pintrk('track', 'pagevisit');
						break;
					case 'insuredSportSelectionView':
						fbq('track', 'ViewContent');
						pintrk('track', 'pagevisit');
						break;
					case 'insuredIndividualSportSelection':
						break;
					case 'policyDatesView':
						fbq('track', 'ViewContent');
						pintrk('track', 'pagevisit');
						break;
					case 'customerInfoView':
						break;
					case 'quickOfferView':
						break;
					case 'summary':
						break;
					case 'checkout':
						fbq('track', 'AddPaymentInfo');
						pintrk('track', 'pagevisit');
						break;
					case 'thanks':
						break;
					case 'quote-error-view':
						break;
				}
				return;
			}
			//
			if (eventType === 'onQuote') {
				umami.track(e.eventType, { ion: offeringOptions?.ion, channelUrl, attributionId });

				console.log('add to cart fired', data);
				//
				gtag('event', 'add_to_cart', {
					currency: 'USD',
					value: data.pricing,
					items: [{
						item_id: 'SIC',
						// item_name: "POMI",
						affiliation: 'POMI_WEBSITE',
						item_brand: 'POMI',
						// item_list_id: "POMI",
						// location_id: "POMI",
						price: data.pricing,
						quantity: 1
					}],
					attributionId: attributionId
				});
				//
				fbq('track', 'AddToCart');
				pintrk('track', 'addtocart', {
					value: data.pricing,
					order_quantity: 1,
					currency: 'USD'
				});
				return;
			}
			//
			// built in GA event
			if (eventType === 'onCheckout' && data.checkoutStatus === 'start') {
				umami.track(e.eventType, {
					checkoutStatus: e.data.checkoutStatus, orderID: e.data.orderID, ion: offeringOptions?.ion, channelUrl, attributionId
				});
				gtag('event', 'add_payment_info', {
					currency: 'USD',
					value: formatPremiumForGA(data.premium),
					payment_type: 'Credit Card',
					items: [{
						item_id: 'SIC',
						// item_name: "POMI",
						affiliation: 'POMI_WEBSITE',
						item_brand: 'POMI',
						// item_list_id: "POMI",
						// location_id: "POMI",
						price: formatPremiumForGA(data.premium),
						quantity: 1
					}],
					attributionId: attributionId
				});
				gtag('event', 'begin_checkout', {
					...dataToSend,
					currency: 'USD',
					value: formatPremiumForGA(data.premium)
				});
				return;
			}
			// built in GA event
			if (eventType === 'onCheckout' && data.checkoutStatus === 'success') {
				//
				umami.track(e.eventType, {
					checkoutStatus: e.data.checkoutStatus, orderID: e.data.orderID, ion: offeringOptions?.ion, channelUrl, attributionId
				});
				gtag('event', 'purchase', {
					transaction_id: dataToSend.orderID,
					value: formatPremiumForGA(data.premium),
					currency: 'USD',
					items: [{
						item_id: 'SIC',
						// item_name: "POMI",
						affiliation: 'POMI_WEBSITE',
						item_brand: 'POMI',
						// item_list_id: "POMI",
						// location_id: "POMI",
						price: formatPremiumForGA(data.premium),
						quantity: 1
					}],
					attributionId: attributionId
				});
				//
				fbq('track', 'Purchase', {
					value: formatPremiumForGA(data.premium),
					currency: 'USD'
				});
				//
				pintrk('track', 'checkout', {
					value: formatPremiumForGA(data.premium),
					order_quantity: 1,
					currency: 'USD',
					event_id: 'eventId0001',
					product_ids: ['1414', '1415']
				});
				//
				return;
			}
			//
			if (eventType === 'onCheckout' && data.checkoutStatus === 'error') {
				umami.track(e.eventType, {
					checkoutStatus: e.data.checkoutStatus, orderID: e.data.orderID, ion: offeringOptions?.ion, channelUrl, attributionId
				});
				gtag('event', 'failed_checkout', {
					...dataToSend,
					currency: 'USD',
					value: formatPremiumForGA(data.premium),
					error_message: data.checkoutError,
				});
				return;
			}
			//
			if (eventType === 'onValidationError') {
				umami.track(e.eventType, {
					elementId: e.data.elementId, validationError: e.data.validationError, ion: offeringOptions?.ion, channelUrl, attributionId
				});
				gtag('event', 'validation_error', dataToSend);
				return;
			}
			if (eventType === 'onExternalLink') {
				umami.track(e.eventType, { externalLinkUrl: e.data.externalLinkUrl, ion: offeringOptions?.ion, channelUrl, attributionId });

				gtag('event', 'external_link_click', dataToSend);
				return;
			}
			if (eventType === 'onCheckboxSelection') {
				umami.track(e.eventType, {
					elementId: e.data.elementId, checked: e.data.checked, value: e.data.value, ion: offeringOptions?.ion, channelUrl, attributionId
				});
				gtag('event', 'checkbox_selection', dataToSend);
				return;
			}
			if (eventType === 'onRadioSelection') {
				umami.track(e.eventType, {
					elementId: e.data.elementId, value: e.data.value, ion: offeringOptions?.ion, channelUrl, attributionId
				});
				gtag('event', 'radio_selection', dataToSend);
				return;
			}
			// DEFAULT
			gtag('event', eventType, dataToSend);
		}

	},
	// themePomi
	themePomi: {
		baseTheme: 'base',
		palette: 'base',
		overrides: {
			styles: {
				'[data-id="errorImage"]': {
					height: '227px',
					width: '290px'
				},
				'.card': {
					'@media (max-width: 460px)': {
						padding: '1rem!important'
					}
				},
				'.radio-button-wrapper': {
					display: 'flex!important',
					'.radio-button-option-wrapper:nth-child(2)': {
						marginLeft: '2rem!important'
					}
				},
				'#policy-registrationFees-field-container': {
					marginTop: '0!important'
				},
				'label[for=policy-registrationFees], #policy-registrationFees': {
					display: 'none'
				},
				'#policy-utility-singleSports-radio-button-wrapper > div:nth-child(2)': {
					marginLeft: '0rem!important'
				},
				'.progress-bar-container': {
					marginBottom: '2rem!important'
				},
				'#offer-container': {
					maxWidth: '1060px',
					margin: '0 auto',
					minHeight: '400px'
				},
				'#offerView-view-container': {
					width: '100%',
					marginTop: '2rem!important',
					'@media (max-width: 768px)': {
						display: 'flex',
						flexWrap: 'wrap',
					}
				},
				'#quickOfferView-content-container-2 > h2::before': {
					content: "'$'",
					textTransform: 'lowercase',
					verticalAlign: 'super',
					fontSize: '2rem',
					// '@media(max-width:660px)': {
					// 	fontSize: '12px',
					// },
				},
				'#customerInfoView-content-container-6': {
					marginTop: '1rem!important',
				},
				'label[for=policy-utility-manuallyEnterAddress]': {
					display: 'none'
				},
				'#powered-by-buddy-container': {
					display: 'none'
				},
				'#offerView-content-container-0, #offerView-content-container-1, #offerView-content-container-2, #offerView-content-container-3': {
					display: 'block',
					flexDirection: 'row', // ensures the elements are in a row
					justifyContent: 'space-between',
				},
				'.view-container#offerView-view-container::before': {
					content: '""',
					float: 'left',
					display: 'block',
					background: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/soccergirl.png") no-repeat top center',
					backgroundSize: 'contain',
					width: '350px',
					height: '500px',
					order: -1,
					alignItems: 'center',
					marginRight: '20px',
					'@media (max-width: 960px)': {
						float: 'none',
						height: '270px',
						marginLeft: 'auto',
						marginRight: 'auto',
					},
				},
				'#checkout-content-container-0::before, #checkout-content-container-1::before': {
					content: '""',
					position: 'relative',
					left: '-96px',
					top: '96px',
					display: 'block',
					background: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/greenDotCircle.png") no-repeat center',
					backgroundSize: 'contain',
					width: '90px',
					height: '90px',
					'@media (max-width: 768px)': {
						display: 'none'
					}
				},
				'#checkout-content-container-0::after, #checkout-content-container-1::after': {
					content: '""',
					position: 'absolute',
					left: '550px',
					top: '160px',
					display: 'block',
					background: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/blueCirlce.png") no-repeat center',
					backgroundSize: 'contain',
					width: '90px',
					height: '90px',
					'@media (max-width: 860px)': {
						display: 'none'
					}
				},
				'#insuredInfoView-content-container-0::before': {
					content: '""',
					position: 'absolute',
					marginTop: '-2%',
					display: 'block',
					background: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/greenDotCircle.png") no-repeat center',
					backgroundSize: 'contain',
					width: '90px',
					height: '90px',
					'@media (max-width: 960px)': {
						display: 'none'
					}
				},
				'#policy-utility-replaceCoverage-field-container .input-error, #policy-utility-trackAndFieldSports-field-container .input-error, #policy-utility-footballSports-field-container .input-error, #policy-utility-waterSports-field-container .input-error, #policy-utility-winterSports-field-container .input-error, #policy-utility-otherSports-field-container .input-error, #policy-utility-baseballSports-field-container .input-error, #policy-utility-sportsCampCheckBox-field-container .input-error, #policy-utility-dcAcaCompliantRule, label[for=policy-utility-dcAcaCompliantRule], #policy-utility-dcBenefitsLimitedRule, label[for=policy-utility-dcBenefitsLimitedRule]': {
					display: 'none'
				},
				'#policyDatesView-content-container-1::before, #policyDatesView-content-container-0::before': {
					content: '""',
					position: 'absolute',
					top: '4rem',
					display: 'block',
					background: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/greenDotCircle.png") no-repeat center',
					backgroundSize: 'contain',
					width: '100px',
					height: '100px',
					'@media (max-width: 960px)': {
						display: 'none'
					}
				},
				'#insuredInfoView-content-container-4': {
					zIndex: '99',
					position: 'relative',
				},
				'#insuredInfoView-content-container-3::after': {
					content: '""',
					position: 'absolute',
					marginLeft: '85%',
					marginTop: '-3rem',
					background: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/blueCirlce.png") no-repeat center',
					backgroundSize: 'contain',
					width: '90px',
					height: '90px',
					'@media (max-width: 960px)': {
						display: 'none'
					},
				},
				'#policyDatesView-content-container-10': {
					marginBottom: '5rem',
					'@media (max-width: 960px)': {
						marginBottom: '0!important'
					},
				},
				'#policyDatesView-content-container-10::after': {
					content: '""',
					position: 'absolute',
					marginLeft: '30%',
					marginTop: '-.5rem',
					background: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/blueCirlce.png") no-repeat center',
					backgroundSize: 'contain',
					width: '100px',
					height: '100px',
					'@media (max-width: 960px)': {
						display: 'none'
					},
				},
				'#checkout-content-container-0, #checkout-content-container-1': {
					position: 'relative',
					textAlign: 'center',
					'@media (max-width: 660px)': {
						textAlign: 'left',
					}

				},
				'#insuredInfoView-content-container-3': {
					position: 'relative',
					marginTop: '1rem'
				},
				'#offerView-content-container-0 h2': {
					color: 'var(--color-primary)',
					fontWeight: 'bold!important',
					marginBottom: '0rem!important',
					'@media (max-width: 480px)': {
						fontSize: '1.75rem!important',
						lineHeight: '2rem!important',
					}
				},
				'#offerView-content-container-2 p > strong': {
					color: 'var(--color-primary)'
				},
				'#offerView-content-container-3': {
					width: '100%',
				},
				'#offerView-content-container-4': {
					'@media (max-width: 660px)': {
						width: '100%!important',
					}
				},
				'#offerView-content-container-4 #policy-utility-offerCustomerFirstNameUi-field-container, #offerView-content-container-4 #policy-utility-offerCustomerLastNameUi-field-container, #offerView-content-container-4 #customer-email-field-container, #offerView-content-container-4 #policy-state-field-container': {
					width: '100%',
					marginTop: '1rem!important',
					'@media (min-width: 960px)': {
						maxWidth: '28%',
						minWidth: '28%',
						display: 'inline-grid',
						marginRight: '1%'
					}
				},
				'#customerInfoView-content-container-1 #customer-firstName-field-container, #customerInfoView-content-container-1 #customer-lastName-field-container, #customerInfoView-content-container-6 #customer-email-field-container, #customerInfoView-content-container-6 #customer-phone-field-container': {
					width: '100%',
					marginTop: '1rem!important',
					'@media (min-width: 768px)': {
						maxWidth: '49%',
						minWidth: '49%',
						maxHeight: 'unset',
						display: 'inline-grid',
						marginRight: '1%',
						marginTop: '0px!important'
					}
				},
				'#policy-state-field-container, #customer-email-field-container': {
					width: '100%',
					marginTop: '1rem!important',
					'@media (min-width: 960px)': {
						maxWidth: '24%',
						minWidth: '24%',
						display: 'inline-grid',
						marginRight: '1%'
					}
				},
				'#insuredSportSelectionView-content-container-1 h2, #insuredSportSelectionView-content-container-0 h2, #leagueInformation-content-container-0, #leagueInformation-content-container-2': {
					color: 'var(--color-primary)',
				},
				'#insuredInfoView-content-container-0 h2, #insuredInfoView-content-container-0 p': {
					color: 'var(--color-primary)',
					position: 'relative',
					textAlign: 'center',
					'@media (max-width: 660px)': {
						textAlign: 'left',
					}
				},
				'#insuredInfoView-view-container': {
					marginBottom: '2rem!important',
				},
				'#insuredInfoView-content-container-2 #policy-utility-offerCustomerFirstNameUi-field-container, #insuredInfoView-content-container-2 #policy-utility-offerCustomerLastNameUi-field-container, #policy-utility-insuredFirstNameUi-field-container, #policy-utility-insuredLastNameUi-field-container, #policy-insuredDob-field-container, #policy-insuredGender-field-container': {
					'@media (min-width: 768px)': {
						width: '49%',
						display: 'inline-grid!important',
						marginRight: '1%'
					}
				},
				'#policy-utility-offerCustomerFirstNameUi-field-container::after': {
					content: '"Parent/Guardian if insured is under 18"',
					paddingTop: '6px',
					color: 'rgba(10, 36, 45, 0.6)',
					fontSize: '.775rem',
				},
				'#insuredSportSelectionView-content-container-1, #insuredSportSelectionView-content-container-0': {
					textAlign: 'center',
					marginBottom: '2rem!important',
					marginTop: '.5rem!important',
					'@media (max-width: 660px)': {
						textAlign: 'left',
					}
				},
				'#policy-utility-singleSports-radio-button-wrapper': {
					alignItems: 'center',
					display: 'grid!important',
					margin: '0 2rem',
					gridTemplateColumns: 'repeat(4, 1fr)',
					gridGap: '1rem',
					'@media (max-width: 768px)': {
						gridTemplateColumns: 'repeat(3, 1fr)',
					},
					'@media (max-width: 600px)': {
						margin: '0 1rem 0 0',
					},
					'@media (max-width: 350px)': {
						gridTemplateColumns: 'repeat(2, 1fr)',
					},
				},
				'#policy-utility-singleSports-radio-button-wrapper input[type=radio] + label': {
					color: 'var(--color-primary)',
					fontWeight: 'bold',
					'@media (max-width: 768px)': {
						fontSize: '12px',
					},
				},
				'#insuredIndividualSportSelection-content-container-6::after, #insuredIndividualSportSelection-content-container-7::after, #insuredIndividualSportSelection-content-container-2::after, #insuredIndividualSportSelection-content-container-3::after, #insuredIndividualSportSelection-content-container-4::after, #insuredIndividualSportSelection-content-container-5::after': {
					content: '""',
					position: 'absolute',
					display: 'block',
					background: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/greenCircles.png") no-repeat center',
					backgroundSize: 'contain',
					marginLeft: '500px',
					marginBottom: '2rem',
					width: '150px',
					height: '150px',
					bottom: '5%',
					'@media (max-width: 768px)': {
						display: 'none'
					}
				},
				'label[for=policy-utility-singleSports-baseball]::before, label[for=policy-utility-singleSports-basketball]::before, label[for=policy-utility-singleSports-cheer]::before, label[for=policy-utility-singleSports-football]::before, label[for=policy-utility-singleSports-gymnastics]::before, label[for=policy-utility-singleSports-soccer]::before, label[for=policy-utility-singleSports-softball]::before, label[for=policy-utility-singleSports-trackAndField]::before, label[for=policy-utility-singleSports-volleyball]::before, label[for=policy-utility-singleSports-waterSports]::before, label[for=policy-utility-singleSports-winterSports]::before, label[for=policy-utility-singleSports-otherSports]::before': {
					display: 'block',
					backgroundRepeat: 'no-repeat',
					backgroundSize: 'contain',
					backgroundPosition: 'center',
					content: "''",
					width: '75px',
					height: '75px',
					textAlign: 'center',
					marginLeft: 'auto',
					marginRight: 'auto',
					marginBottom: '4px',
				},
				'label[for=policy-utility-singleSports-baseball], label[for=policy-utility-singleSports-basketball], label[for=policy-utility-singleSports-cheer], label[for=policy-utility-singleSports-football], label[for=policy-utility-singleSports-gymnastics], label[for=policy-utility-singleSports-soccer], label[for=policy-utility-singleSports-softball], label[for=policy-utility-singleSports-trackAndField], label[for=policy-utility-singleSports-volleyball], label[for=policy-utility-singleSports-waterSports], label[for=policy-utility-singleSports-winterSports], label[for=policy-utility-singleSports-otherSports]': {
					textAlign: 'center',
				},
				'label[for=policy-utility-singleSports-baseball]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/icon_baseball_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-baseball]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/icon_baseball_on.png")'
				},
				'label[for=policy-utility-singleSports-basketball]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/icon_basketball_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-basketball]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/icon_basketball_on.png")'
				},
				'label[for=policy-utility-singleSports-cheer]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/icon_cheer_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-cheer]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/icon_cheer_on.png")'
				},
				'label[for=policy-utility-singleSports-football]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/icon_football_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-football]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/icon_football_on.png")'
				},
				'label[for=policy-utility-singleSports-gymnastics]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/icon_gymnastics_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-gymnastics]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/icon_gymnastics_on.png")'
				},
				'label[for=policy-utility-singleSports-soccer]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/icon_soccer_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-soccer]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/icon_soccer_on.png")'
				},
				'label[for=policy-utility-singleSports-softball]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/icon_softball_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-softball]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/icon_softball_on.png")'
				},
				'label[for=policy-utility-singleSports-trackAndField]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/icon_trackfield_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-trackAndField]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/icon_trackfield_on.png")'
				},
				'label[for=policy-utility-singleSports-volleyball]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/icon_volleyball_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-volleyball]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/icon_volleyball_on.png")'
				},
				'label[for=policy-utility-singleSports-waterSports]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/icon_watersports_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-waterSports]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/icon_watersports_on.png")'
				},
				'label[for=policy-utility-singleSports-winterSports]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/wintersports_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-winterSports]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/wintersports_on.png")'
				},
				'label[for=policy-utility-singleSports-otherSports]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/icon_othersports_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-otherSports]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/icon_othersports_on.png")'
				},
				'#policy-utility-singleSports-radio-button-wrapper .radio-button, label[for=policy-utility-singleSports]': {
					display: 'none'
				},
				'#policy-utility-singleSports-radio-button-wrapper .radio-button-option-wrapper': {
					display: 'flex',
					justifyContent: 'center',
					marginRight: '0',
				},
				'#insuredIndividualSportSelection-content-container-0, #insuredIndividualSportSelection-content-container-1': {
					textAlign: 'center',
					marginBottom: '2rem!important',
					'@media (max-width: 660px)': {
						textAlign: 'left',
					}

				},
				'#leagueInformation-content-container-0, #leagueInformation-content-container-2, #leagueInformation-content-container-3 > p': {
					textAlign: 'center',
					'@media (max-width: 660px)': {
						textAlign: 'left',
					}
				},
				'#insuredIndividualSportSelection-content-container-7, #insuredIndividualSportSelection-content-container-2, #insuredIndividualSportSelection-content-container-3, #insuredIndividualSportSelection-content-container-4, #insuredIndividualSportSelection-content-container-5, #insuredIndividualSportSelection-content-container-6, #leagueInformation-content-container-1, #leagueInformation-content-container-4, #leagueInformation-content-container-5, #leagueInformation-content-container-6': {
					margin: '0 auto',
					width: '70%',
					'@media (max-width: 660px)': {
						width: '100%',
					}

				},
				'#policyDatesView-view-container': {
					textAlign: 'center',
					alignItems: 'center',
					position: 'relative',
					'@media (max-width: 660px)': {
						textAlign: 'left',
					}
				},
				'#policy-seasonStartDate-field-container, #policy-seasonEndDate-field-container': {
					'@media (min-width: 860px)': {
						maxWidth: '30%',
						minWidth: '30%',
						display: 'inline-grid',
						marginRight: '1%'
					}
				},
				'#policyDatesView-content-container-0 > p,': {
					marginBottom: '0!important',
				},
				'#policyDatesView-content-container-2': {
					p: {
						fontSize: '0.8rem!important',
						marginBottom: '1rem!important',
						marginTop: '1rem!important'
					},
					'p:nth-child(1)': {
						marginBottom: '0rem!important',
						marginTop: '2rem!important'
					},
					'p:nth-child(2)': {
						marginBottom: '2rem!important',
						marginTop: '0rem!important',
						fontSize: '0.7rem!important',
						fontWeight: 'bold!important'
					}
				},
				'#leagueInformation-content-container-2': {
					margin: '0 auto',
					marginTop: '2rem',
					maxWidth: '90%',
					'@media (max-width: 660px)': {
						maxWidth: 'unset',
					}

				},
				// '#leagueInformation-content-container-2 > h2': {
				// 	maxWidth: '75%'
				// },
				'#quote-price-label-container, #quickOfferView-view-title, #policy-utility-mobilePhoneCheckBox-field-container > label': {
					display: 'none'
				},
				'#policy-utility-mobilePhoneCheckBox-checkbox-wrapper > label': {
					color: 'rgba(10, 36, 45, 0.6)',
					fontSize: '14px'
				},
				'#quickOfferView-content-container-2': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/quoteImg.png")',
					backgroundRepeat: 'no-repeat',
					backgroundSize: 'contain',
					content: "''",
					width: '350px',
					height: '350px',
					float: 'left',
					paddingLeft: '10px',
					display: 'inline-block',
					justifyContent: 'center',
					alignItems: 'center',
					textAlign: 'center',
					marginTop: '1rem',
					'@media (max-width: 768px)': {
						width: '300px',
						height: '250px',
						justifyContent: 'center',
						alignItems: 'center',
						margin: 'auto 1rem'
					}
				},
				'#quickOfferView-content-container-2 h2': {
					marginTop: '110px',
					marginRight: '6rem',
					textAlign: 'center',
					fontFamily: 'Poppins, sans-serif',
					marginBottom: '0 !important',
					color: 'rgb(255, 255, 255) !important',
					fontSize: '65px !important',
					fontWeight: 'bold !important',
					opacity: 0, // start with opacity 0
					animation: 'fadeIn 0.5s ease 1.5s forwards', // 2s duration, 2s delay
					'@keyframes fadeIn': {
						from: { opacity: 0 },
						to: { opacity: 1 }
					},
					'@media (max-width: 768px)': {
						marginTop: '90px',
						marginRight: '5rem',
						textAlign: 'center',
						color: '#FFFFFF!important',
						fontSize: '55px!important',
						fontWeight: 'bold!important'
					}
				},
				'#quickOfferView-content-container-2 p': {
					color: '#FFFFFF!important',
					textAlign: 'left',
					// marginTop: '120px',
					marginTop: '0rem!important',
					marginBottom: '0rem!important',
					marginLeft: '1.5rem',
					fontSize: '12px!important',
					'@media (max-width: 768px)': {
						fontSize: '12px!important',
						marginLeft: '.5rem',
						marginTop: '140px'
					},
					'@media (max-width: 410px)': {
						marginLeft: '1.1rem',
						fontSize: '10px!important'
					},
				},
				'#quickOfferView-content-container-2 > p:nth-child(2)': {
					marginTop: '0.25rem!important',
					marginLeft: '70px!important',
					fontWeight: 'bold!important',
					'@media (max-width: 768px)': {
						marginLeft: '50px!important',
					},
				},
				'#quickOfferView-content-container-2 > p:nth-child(3)': {
					marginLeft: '45px!important',
					'@media (max-width: 768px)': {
						marginLeft: '26px!important'
					}
				},
				'#quickOfferView-content-container-0 h2, #quickOfferView-content-container-1 h2': {
					marginTop: '100px',
					marginLeft: '3rem',
					marginRight: '2rem',
					textAlign: 'left',
					lineHeight: '3rem!important',
					'@media (max-width: 768px)': {
						marginLeft: '0rem!important',
						marginRight: '0rem!important',
						// textAlign: 'center',
						fontSize: '30px!important',
						marginTop: '2rem'
					}
				},
				'#quickOfferView-view-container': {
					position: 'relative',
					textAlign: 'right',
					paddingLeft: '20px',
					'@media (max-width: 960px)': {
						textAlign: 'left',
						paddingLeft: '0'
					},
				},
				'#quickOfferView-content-container-1, #quickOfferView-content-container-0': {
					width: '49%',
					float: 'left',
					paddingRight: '20px',
					display: 'flex',
					justifyContent: 'center',
					alignItems: 'center',
					textAlign: 'center',
					marginBottom: '4rem!important',
					'@media (max-width: 768px)': {
						width: '100%',
						marginBottom: '0px!important'
					}
				},
				'#customerInfoView-content-container-5 > p, #policyDatesView-content-container-6 > p, #policyDatesView-content-container-7 > p': {
					color: '#d62719!important'
				},
				'#customerInfoView-content-container-10 > p': {
					textAlign: 'center',
					marginTop: '4rem!important'
				},
				table: {
					borderCollapse: 'collapse',
					margin: '0 auto',
					marginBottom: '.5rem',
					padding: '.25rem',
					minWidth: '90%',
					width: '90%',
					tableLayout: 'inherit',
					fontColor: 'black',
					'@media (max-width: 600px)': {
						border: 0
					}
				},
				'#summary-content-container-2 > table > thead > tr > th:nth-child(2), #summary-content-container-4 > table > thead > tr > th:nth-child(2), #summary-content-container-6 > table > thead > tr > th:nth-child(2), #summary-content-container-8 > table > thead > tr > th:nth-child(2)': {
					'@media (max-width: 600px)': {
						display: 'flex',
						justifyContent: 'space-between',
						'font-size': '.8em'
					}

				},
				'#quickOfferView-content-container-3 > table > tbody > tr:nth-child(1) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Accident'",
						display: 'block',
						'font-size': '1.5em',
						color: 'var(--color-primary)'
					}
				},
				'#quickOfferView-content-container-3 > table > tbody > tr:nth-child(2) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Sickness'",
						display: 'block',
						'font-size': '1.5em',
						color: 'var(--color-primary)'
					}
				},
				'#quickOfferView-content-container-3 > table > tbody > tr:nth-child(3) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Accidental Death & Dismemberment'",
						display: 'block',
						'font-size': '1.5em',
						color: 'var(--color-primary)'
					}
				},
				'#quickOfferView-content-container-4 > table > tbody > tr:nth-child(1) > td:nth-child(2):before, #quickOfferView-content-container-5 > table > tbody > tr:nth-child(1) > td:nth-child(2):before, #quickOfferView-content-container-6 > table > tbody > tr:nth-child(1) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'24 Hour Accident'",
						display: 'block',
						'font-size': '1.5em',
						color: 'var(--color-primary)'
					}
				},
				'#quickOfferView-content-container-4 > table > tbody > tr:nth-child(2) > td:nth-child(2):before, #quickOfferView-content-container-6 > table > tbody > tr:nth-child(2) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'24 Hour Sickness'",
						display: 'block',
						'font-size': '1.5em',
						color: 'var(--color-primary)'
					}
				},
				'#quickOfferView-content-container-4 > table > tbody > tr:nth-child(3) > td:nth-child(2):before, #quickOfferView-content-container-5 > table > tbody > tr:nth-child(2) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'24 Hour Accidental Death & Dismemberment'",
						display: 'block',
						'font-size': '1.5em',
						color: 'var(--color-primary)'
					}
				},
				'#quickOfferView-content-container-3 > table > tbody > tr:nth-child(1) > td:nth-child(3):before, #quickOfferView-content-container-3 > table > tbody > tr:nth-child(2) > td:nth-child(3):before, #quickOfferView-content-container-3 > table > tbody > tr:nth-child(3) > td:nth-child(3):before': {
					'@media (max-width: 600px)': {
						content: "'Coverage Information'"
					}
				},
				'#quickOfferView-content-container-4 > table > tbody > tr:nth-child(1) > td:nth-child(3):before, #quickOfferView-content-container-4 > table > tbody > tr:nth-child(2) > td:nth-child(3):before, #quickOfferView-content-container-4 > table > tbody > tr:nth-child(3) > td:nth-child(3):before': {
					'@media (max-width: 600px)': {
						content: "'Coverage Information'"
					}
				},
				'#quickOfferView-content-container-5 > table > tbody > tr:nth-child(1) > td:nth-child(3):before, #quickOfferView-content-container-5 > table > tbody > tr:nth-child(2) > td:nth-child(3):before, #quickOfferView-content-container-5 > table > tbody > tr:nth-child(3) > td:nth-child(3):before': {
					'@media (max-width: 600px)': {
						content: "'Coverage Information'"
					}
				},
				'#quickOfferView-content-container-6 > table > tbody > tr:nth-child(1) > td:nth-child(3):before, #quickOfferView-content-container-6 > table > tbody > tr:nth-child(2) > td:nth-child(3):before, #quickOfferView-content-container-6 > table > tbody > tr:nth-child(3) > td:nth-child(3):before': {
					'@media (max-width: 600px)': {
						content: "'Coverage Information'"
					}
				},
				'#customerInfoView-content-container-0 > h2': {
					textAlign: 'center',
					'@media (max-width: 660px)': {
						textAlign: 'left',
					}

				},
				'#insuranceReplacementView-view-container': {
					marginTop: '2rem!important',
				},
				'#summary-content-container-1,#summary-content-container-2, #summary-content-container-3, #summary-content-container-4, #summary-content-container-5, #summary-content-container-6, #summary-content-container-7, #summary-content-container-8': {
					table: {
						borderCollapse: 'collapse',
						margin: '0 auto',
						marginBottom: '.5rem',
						padding: '.25rem',
						minWidth: '90%',
						width: '90%',
						tableLayout: 'inherit',
						fontColor: 'black',
						'@media (max-width: 600px)': {
							border: 0,
							width: '100%'
						}
					},
					caption: {
						fontSize: '1.5em',
						margin: '.5em 0 .75em',
						'@media (max-width: 600px)': {
							border: 0
						}
					},
					'table tr': {
						backgroundColor: '#fff',
						border: '1px solid #ddd',
						'@media (max-width: 600px)': {
							display: 'block'
						}
					},
					'table th': {
						fontSize: '.95em',
						'@media (max-width: 600px)': {}
					},
					'table th, table td': {
						padding: '.625em',
						'@media (max-width: 600px)': {}
					},
					'table td': {
						'@media (max-width: 600px)': {
							borderBottom: '1px solid #ddd',
							display: 'block',
							fontSize: '.8em',
							textAlign: 'right',
							minHeight: '35px'
						}
					},
					'thead > tr > th:first-child': {
						'@media (max-width: 600px)': {
							display: 'none'
						}
					},
					'tbody > tr > td:first-child': {
						'@media (max-width: 600px)': {
							display: 'none'
						}
					},
					'table > tbody > tr > td:nth-child(2), thead > tr > th:nth-child(2)': {
						'@media (max-width: 600px)': { width: '100%!important' }
					},
					'tbody > tr > td:last-child': {
						'@media (max-width: 600px)': {
							paddingRight: '.5rem',
							textAlign: 'right'
						}
					},
					'td:before, th:before': {
						'@media (max-width: 600px)': {
							float: 'left',
							fontWeight: 'bold',
							textTransform: 'uppercase',
							paddingRight: '.5rem'
						}
					},
				},
				'#summary-content-container-1, #summary-content-container-3, #summary-content-container-5, #summary-content-container-7': {
					'thead > tr > th:first-child': {
						'@media (max-width: 600px)': {
							display: 'block'
						}
					},
				},
				'#quickOfferView-content-container-3, #quickOfferView-content-container-4, #quickOfferView-content-container-5, #quickOfferView-content-container-6': {
					table: {
						borderCollapse: 'collapse',
						margin: '0 auto',
						marginBottom: '.5rem',
						padding: '.25rem',
						minWidth: '90%',
						width: '90%',
						tableLayout: 'inherit',
						fontColor: 'black',
						'@media (max-width: 600px)': {
							border: 0,
							width: '100%'
						}
					},
					thead: {
						'@media (max-width: 600px)': {
							border: 'none',
							clip: 'rect(0 0 0 0)',
							height: '1px',
							margin: '-1px',
							overflow: 'hidden',
							padding: 0,
							position: 'absolute',
							width: '1px'
						}
					},
					caption: {
						fontSize: '1.5em',
						margin: '.5em 0 .75em',
						'@media (max-width: 600px)': {
							border: 0
						}
					},
					'table tr': {
						backgroundColor: '#fff',
						border: '1px solid #ddd',
						'@media (max-width: 600px)': {
							display: 'block'
						}
					},
					'table th': {
						fontSize: '.95em',
						'@media (max-width: 600px)': {}
					},
					'table th, table td': {
						padding: '.625em',
						// textAlign: 'center',
						'@media (max-width: 600px)': {}
					},
					'table td': {
						'@media (max-width: 600px)': {
							borderBottom: '1px solid #ddd',
							display: 'block',
							fontSize: '.8em',
							textAlign: 'left',
							minHeight: '35px'
						}
					},
					'thead > tr > th:first-child': {
						'@media (max-width: 600px)': {
							display: 'none'
						}
					},
					'tbody > tr > td:first-child': {
						'@media (max-width: 600px)': {
							display: 'none'
						}
					},
					'table > tbody > tr > td:nth-child(2), thead > tr > th:nth-child(2)': {
						'@media (max-width: 600px)': { width: '100%!important' }
					},
					'tbody > tr > td:last-child': {
						'@media (max-width: 600px)': {
							paddingRight: '.5rem',
							textAlign: 'left'
						}
					},
					'td:before, th:before': {
						'@media (max-width: 600px)': {
							display: 'block',
							fontWeight: 'bold',
							textTransform: 'uppercase',
							paddingRight: '.5rem'
						}
					},
				},
				'#summary-content-container-2 > table > thead > tr > th:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Name'"
					}
				},
				'#summary-content-container-2 > table > tbody > tr:nth-child(1) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'DOB'"
					}
				},
				'#summary-content-container-2 > table > tbody > tr:nth-child(2) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Policy Dates'"
					}
				},
				'#summary-content-container-2 > table > tbody > tr:nth-child(3) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Gender'"
					}
				},
				'#summary-content-container-2 > table > tbody > tr:nth-child(4) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Sport'"
					}
				},
				'#summary-content-container-2 > table > tbody > tr:nth-child(5) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'League/Team'"
					}
				},
				'#summary-content-container-4 > table > thead > tr > th:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'League/Team Name'"
					}
				},
				'#summary-content-container-4 > table > tbody > tr:nth-child(1) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Season Dates'"
					}
				},
				'#summary-content-container-4 > table > tbody > tr:nth-child(2) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Registration Fees'"
					}
				},
				'#summary-content-container-4 > table > tbody > tr:nth-child(3) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Premium'"
					}
				},
				'#summary-content-container-6 > table > thead > tr > th:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Name'"
					}
				},
				'#summary-content-container-6 > table > tbody > tr:nth-child(1) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Address'"
					}
				},
				'#summary-content-container-6 > table > tbody > tr:nth-child(2) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Mobile Number'"
					}
				},
				'#summary-content-container-6 > table > tbody > tr:nth-child(3) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Email'"
					}
				},
				'#summary-content-container-8 > table > thead > tr > th:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Name'"
					}
				},
				'#summary-content-container-8 > table > tbody > tr:nth-child(1) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Address'"
					}
				},
				'#quickOfferView-content-container-3 > table > thead > tr > th, #quickOfferView-content-container-4 > table > thead > tr > th, #quickOfferView-content-container-5 > table > thead > tr > th, #quickOfferView-content-container-6 > table > thead > tr > th': {
					backgroundColor: 'var(--color-primary)',
					color: '#FFF'
				},
				'#quickOfferView-content-container-3 > table, #quickOfferView-content-container-4 > table, #quickOfferView-content-container-5 > table, #quickOfferView-content-container-6 > table': {
					maxWidth: 'none!important'
				},
				'#quickOfferView-content-container-3 > table > thead > tr > th > nth-child(1), #quickOfferView-content-container-4 > table > thead > tr > th > nth-child(1), #quickOfferView-content-container-5 > table > thead > tr > th > nth-child(1), #quickOfferView-content-container-6 > table > thead > tr > th > nth-child(1)': {
					paddingLeft: '0px!important'
				},
				'#summary-content-container-1 > table > thead > tr > th, #summary-content-container-3 > table > thead > tr > th, #summary-content-container-5 > table > thead > tr > th, #summary-content-container-7 > table > thead > tr > th': {
					fontWeight: 'bold',
					color: '#FFF!important',
					paddingBottom: '1rem!important'
				},
				'#summary-content-container-1 > table > thead > tr, #summary-content-container-3 > table > thead > tr > th, #summary-content-container-5 > table > thead > tr > th, #summary-content-container-7 > table > thead > tr > th': {
					backgroundColor: 'var(--color-primary)',
					color: '#FFF'
				},
				'#summary-content-container-0 > table > tbody > tr > td, #summary-content-container-2 > table > thead > tr > th, #summary-content-container-4 > table > thead > tr > th, #summary-content-container-2 > table > tbody > tr > td, #summary-content-container-4 > table > thead > tr > th, #summary-content-container-4 > table > tbody > tr > td, #summary-content-container-6 > table > thead > tr > th, #summary-content-container-6 > table > tbody > tr > td, #summary-content-container-8 > table > thead > tr > th, #summary-content-container-8 > table > tbody > tr > td': {
					fontWeight: '400',
					textAlign: 'left',
					paddingTop: '.6rem',
					paddingBottom: '.6rem',
					backgroundColor: '#FFF!important',
					width: '50%'
				},
				'#summary-content-container-2 > table > thead > tr > th, #summary-content-container-4 > table > thead > tr > th, #summary-content-container-6 > table > thead > tr > th, #summary-content-container-2 > table > tbody > tr > td, #summary-content-container-4 > table > tbody > tr > td, #summary-content-container-6 > table > tbody > tr > td, #summary-content-container-8 > table > tbody > tr > td, #summary-content-container-8 > table > thead > tr > th': {
					color: '#333333!important'
				},
				'#summary-content-container-2 > table > tbody > tr > td, #summary-content-container-2 > table > thead > tr > th, #summary-content-container-4 > table > tbody > tr:nth-child(1) > td:nth-child(2) > a, #summary-content-container-6 > table > thead > tr > th, #summary-content-container-8 > table > thead > tr > th': {
					fontWeight: '400!important',
					backgroundColor: '#FFF!important'
				},
				'#summary-content-container-2, #summary-content-container-4, #summary-content-container-6, #summary-content-container-8': {
					marginTop: '-20px'
				},
				'#policy-electronicSignature-field-container .input-error, #policy-utility-electronicDisclosure-field-container .input-error, #policy-utility-electronicSignature-field-container > label, #policy-utility-electronicDisclosure-field-container > label': {
					display: 'none'
				},
				'.input-error': {
					marginTop: '0rem!important',
				},
				'#policy-utility-manuallyEnterAddress-checkbox-wrapper': {
					marginBottom: '1rem!important'
				},
				'#summary-content-container-2 > table > tbody > tr:nth-child(1), #summary-content-container-2 > table > tbody > tr:nth-child(3), #summary-content-container-4 > table > tbody > tr:nth-child(1), #summary-content-container-4 > table > tbody > tr:nth-child(3), #summary-content-container-6 > table > tbody > tr:nth-child(1), #summary-content-container-8 > table > tbody > tr:nth-child(1)': {
					backgroundColor: '#FFF!important'
				},
				'#summary-content-container-0 > h3': {
					fontWeight: 'normal'
				},
				'#checkout-content-container-2': {
					right: '0',
					width: '100px',
					height: '100px',
					position: 'absolute',
					bottom: '60%',
					'@media (max-width: 768px)': {
						display: 'none'
					}
				},
				'#checkout-content-container-1 h2': {
					lineHeight: '2.25rem!important'
				},
				'#checkout-view-container': {
					minHeight: '150px !important',
					display: 'flex',
					flexDirection: 'column',
					justifyContent: 'center',
					alignItems: 'center',
					textAlign: 'center',
					marginLeft: '10%',
					marginRight: '10%',
					'@media (max-width: 601px)': {
						marginLeft: '0',
						marginRight: '0'
					}
				},
				'#checkout-view-title': {
					display: 'none'
				},
				'#thanks-view-container, #quote-error-view-view-container, #knockoutStateView-view-container, #insuranceReplacementView-view-container, #knockoutComplianceInDcView-view-container': {
					display: 'flex',
					flexDirection: 'column',
					justifyContent: 'center',
					alignItems: 'center',
					textAlign: 'center',
					color: '#333333!important',
					lineHeight: '1',
					'@media (max-width: 660px)': {
						display: 'block',
						textAlign: 'left!important'
					}
				},
				'#insuranceReplacementView-content-container-2::after': {
					content: '""',
					display: 'block',
					background: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/COACHP_JustaMinute.png") no-repeat center',
					backgroundSize: 'contain',
					width: '300px',
					height: '300px',
					margin: '0 auto',
				},
				'#knockoutStateView-content-container-2::after, #knockoutComplianceInDcView-content-container-1::after': {
					content: '""',
					display: 'block',
					background: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/COACH_OhhBummer.png") no-repeat center',
					backgroundSize: 'contain',
					width: '300px',
					height: '300px',
					margin: '0 auto',
				},
				'#knockoutStateView-content-container-0 h2, #quote-error-view-content-container-0 h2, #insuranceReplacementView-content-container-0 h2': {
					fontSize: '50px!important'
				},
				'#knockoutStateView-content-container-1 p, #insuranceReplacementView-content-container-1 p': {
					marginBottom: '0'
				},
				'#knockoutStateView-content-container-1 > p, #knockoutStateView-content-container-2 > p, #insuranceReplacementView-content-container-1 p, #insuranceReplacementView-content-container-2 p, #quote-error-view-content-container-1 p, #quote-error-view-content-container-2 p, #quote-error-view-content-container-3 p, #quote-error-view-content-container-4 p': {
					color: '#333333!important',
					marginTop: '0px!important',
					marginBottom: '1px!important'
				},
				'#thanks-content-container-0::after': {
					content: '""',
					display: 'block',
					background: 'url("https://staging.embed.buddy.insure/gaig/pomi_si/coachCelebration.png") no-repeat center',
					backgroundSize: 'contain',
					width: '300px',
					height: '300px',
					marginLeft: '112px',
					'@media (max-width: 960px)': {
						width: '100%',
						marginLeft: '0'
					},
				},
				'#thanks-content-container-1 > p, #thanks-content-container-2 > p, #thanks-content-container-3 > p, #quote-error-view-content-container-1 > h3': {
					color: '#333333!important',
					marginTop: '0px!important',
					marginBottom: '1px!important'
				},
				'.button-primary': {
					textTransform: 'uppercase',
					transition: 'border-color .4s ease 0s,background-color .4s ease 0s',
					border: '2px solid var(--color-secondary)',
					borderRadius: '5rem !important',
					background: 'var(--color-secondary)',
					padding: '.75rem 1.125rem',
					fontWeight: 'bold',
					fontFamily: 'Poppins, sans-serif',
					fontSize: '13px',
					height: '40px',
					color: '#FFFFFF',
					marginTop: '2rem',
					bottom: '0',
					'&:hover': {
						background: '#FFFFFF',
						color: 'var(--color-primary)'
					},
					'@media (min-width: 768px)': {
						minWidth: 'unset'
					}
				},
				'.button-secondary': {
					textTransform: 'uppercase',
					transition: 'border-color .4s ease 0s,background-color .4s ease 0s',
					border: '2px solid var(--color-secondary)',
					borderRadius: '5rem !important',
					background: 'var(--color-secondary)',
					padding: '.75rem 1.125rem',
					fontWeight: 'bold',
					fontFamily: 'Poppins, sans-serif',
					fontSize: '13px',
					lineHeight: '0px!important',
					marginTop: '2rem!important',
					height: '40px',
					textAlign: 'center',
					color: '#FFFFFF',
					'&:hover': {
						background: '#FFFFFF',
						color: 'var(--color-primary)'
					},
					'@media (min-width: 768px)': {
						minWidth: 'unset'
					}
				},
				button: {
					textTransform: 'uppercase',
					backgroundColor: '#f3f6f9',
					fontWeight: 'bold',
					fontSize: '16px',
					lineHeight: '1',
					padding: '.75rem 1.125rem',
					color: '#fff',
					transition: 'background-color .4s ease 0s',
					borderRadius: '5rem'
				},
				body: {
					fontFamily: 'Poppins, sans-serif',
					fontSize: '16px',
					'@media (min-width: 768px)': {
						fontSize: '16px'
					},
					margin: '0 auto'
				},
				h2: {
					fontFamily: 'Poppins, sans-serif',
					fontWeight: '400!important',
					marginTop: '2rem',
					fontSize: '50px',
					color: 'var(--color-primary)!important',
					'@media (max-width: 768px)': {
						fontSize: '35px!important'
					},
					'@media (max-width: 450px)': {
						fontSize: '30px!important'
					}
				},
				h3: {
					fontFamily: 'Poppins, sans-serif',
					fontWeight: 'bold',
					fontSize: '30px',
					color: 'var(--color-primary)'
				}
			},
			colors: {
				primary: '#5C77DF',
				secondary: '#FF9A52',
				textPrimary: '#333333',
			},
			webFonts: [
				'https://fonts.googleapis.com/css2?family=Poppins:wght@400;700&display=swap'
			]
		}
	},
	themeBase: {
		baseTheme: 'base',
		palette: 'base',
		overrides: {
			styles: {
				'[data-id="errorImage"]': {
					height: '227px',
					width: '290px'
				},
				'div[case=single-form], div[case=paginated],': {
					padding: '1.75rem',
					paddingTop: '0',
					marginLeft: '0',
					minHeight: '400px',
					'@media (min-width: 992px)': {
						marginLeft: '220px',
					},
					'@media (max-width: 660px)': {
						padding: '1rem',
					},
				},
				'.card': {
					backgroundColor: '#FFF',
					textAlign: 'left',
					padding: '0',
					border: '16px solid #F2FAFE',
					'@media (min-width: 992px)': {
						backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/fld/sidebar-bg.png")',
						border: '16px solid var(--color-primary)',
						backgroundSize: '220px',
						backgroundPosition: 'left bottom',
						backgroundRepeat: 'no-repeat',
						borderRadius: 'unset',
					},
				},
				'.radio-button-wrapper': {
					display: 'flex!important',
					'.radio-button-option-wrapper:nth-child(2)': {
						marginLeft: '2rem!important'
					}
				},
				'#policy-registrationFees-field-container': {
					marginTop: '0!important'
				},
				'label[for=policy-registrationFees], #policy-registrationFees': {
					display: 'none'
				},
				'#policy-utility-singleSports-radio-button-wrapper > div:nth-child(2)': {
					marginLeft: '0rem!important'
				},
				'.input-text, .input-select, .input-invalid,': {
					borderRadius: '0!important'
				},
				'.progress-bar-container': {
					marginBottom: '2rem!important',
					borderRadius: '0rem'
				},
				'.progress-bar': {
					backgroundColor: 'var(--color-secondary)',
					'z-index': '20',
					height: '100%',
					borderRadius: '0rem'
				},
				'#offer-container': {
					maxWidth: '1100px',
					margin: '0 auto',
					minHeight: '400px'
				},
				'#offerView-view-container': {
					width: '100%',
					marginTop: '2rem!important',
					'@media (max-width: 768px)': {
						display: 'flex',
						flexWrap: 'wrap',
					}
				},
				'#quickOfferView-content-container-2 > h2::before': {
					content: "'$'",
					textTransform: 'lowercase',
					verticalAlign: 'super',
					fontSize: '1.5rem',
					// '@media(max-width:660px)': {
					// 	fontSize: '12px',
					// },
				},
				'#quickOfferView-content-container-2 > h2': {
					'@media(max-width:660px)': {
						textAlign: 'left',
					},
				},
				'#customerInfoView-content-container-6': {
					marginTop: '1rem!important',
				},
				'label[for=policy-utility-manuallyEnterAddress]': {
					display: 'none'
				},
				'#powered-by-buddy-container': {
					display: 'none'
				},
				'#offerView-content-container-0, #offerView-content-container-1, #offerView-content-container-2, #offerView-content-container-3, #offerView-content-container-4': {
					display: 'block',
					flexDirection: 'row', // ensures the elements are in a row
					justifyContent: 'space-between',
				},
				'.view-container#offerView-view-container::before': {

				},

				'#policy-utility-replaceCoverage-field-container .input-error, #policy-utility-trackAndFieldSports-field-container .input-error, #policy-utility-footballSports-field-container .input-error, #policy-utility-waterSports-field-container .input-error, #policy-utility-winterSports-field-container .input-error, #policy-utility-otherSports-field-container .input-error, #policy-utility-baseballSports-field-container .input-error, #policy-utility-sportsCampCheckBox-field-container .input-error, #policy-utility-dcAcaCompliantRule, label[for=policy-utility-dcAcaCompliantRule], #policy-utility-dcBenefitsLimitedRule, label[for=policy-utility-dcBenefitsLimitedRule]': {
					display: 'none'
				},
				'#policyDatesView-content-container-10': {
					marginBottom: '5rem',
					'@media (max-width: 960px)': {
						marginBottom: '0!important'
					},
				},

				'#checkout-content-container-0, #checkout-content-container-1': {
					position: 'relative',
					textAlign: 'center',
					'@media (max-width: 660px)': {
						textAlign: 'left',
					}
				},
				'#insuredInfoView-content-container-3': {
					position: 'relative',
					marginTop: '1rem'
				},
				'#offerView-content-container-0 h2': {
					color: 'var(--color-primary)',
					fontWeight: 'bold!important',
					marginBottom: '0rem!important',
					'@media (max-width: 480px)': {
						fontSize: '1.75rem!important',
						lineHeight: '2rem!important',
					}
				},
				'#offerView-content-container-1 h2': {
					color: 'var(--color-primary)',
					fontWeight: 'bold!important',
					marginBottom: '0rem!important',
					'@media (max-width: 480px)': {
						fontSize: '1.75rem!important',
						lineHeight: '2rem!important',
					}
				},
				'#offerView-content-container-3 p > strong': {
					color: 'var(--color-primary)'
				},
				'#offerView-content-container-4': {
					width: '100%',
				},
				'#offerView-content-container-4 #policy-utility-offerCustomerFirstNameUi-field-container, #offerView-content-container-4 #policy-utility-offerCustomerLastNameUi-field-container, #offerView-content-container-4 #customer-email-field-container, #offerView-content-container-4 #policy-state-field-container': {
					width: '100%',
					marginTop: '1rem!important',
					'@media (min-width: 960px)': {
						maxWidth: '49%',
						minWidth: '49%',
						display: 'inline-grid',
						marginRight: '1%'
					}
				},
				'#customerInfoView-content-container-1 #customer-firstName-field-container, #customerInfoView-content-container-1 #customer-lastName-field-container, #customerInfoView-content-container-6 #customer-email-field-container, #customerInfoView-content-container-6 #customer-phone-field-container': {
					width: '100%',
					marginTop: '1rem!important',
					'@media (min-width: 768px)': {
						maxWidth: '49%',
						minWidth: '49%',
						maxHeight: 'unset',
						display: 'inline-grid',
						marginRight: '1%',
						marginTop: '0px!important'
					}
				},
				'#policy-state-field-container, #customer-email-field-container': {
					width: '100%',
					marginTop: '1rem!important',
					'@media (min-width: 960px)': {
						maxWidth: '28%',
						minWidth: '28%',
						display: 'inline-grid',
						marginRight: '1%'
					}
				},
				'#insuredSportSelectionView-content-container-1 h2, #insuredSportSelectionView-content-container-0 h2, #leagueInformation-content-container-0, #leagueInformation-content-container-2': {
					color: 'var(--color-primary)',
				},
				'#insuredInfoView-content-container-0 h2, #insuredInfoView-content-container-0 p': {
					color: 'var(--color-primary)',
					position: 'relative',
					textAlign: 'center',
					'@media (max-width: 660px)': {
						textAlign: 'left',
					}
				},
				'#insuredInfoView-view-container': {
					marginBottom: '2rem!important',
				},
				'#insuredInfoView-content-container-2 #policy-utility-offerCustomerFirstNameUi-field-container, #insuredInfoView-content-container-2 #policy-utility-offerCustomerLastNameUi-field-container, #policy-utility-insuredFirstNameUi-field-container, #policy-utility-insuredLastNameUi-field-container, #policy-insuredDob-field-container, #policy-insuredGender-field-container': {
					'@media (min-width: 768px)': {
						width: '49%',
						display: 'inline-grid!important',
						marginRight: '1%'
					}
				},
				'#policy-utility-offerCustomerFirstNameUi-field-container::after': {
					content: '"Parent/Guardian if insured is under 18"',
					paddingTop: '6px',
					color: 'rgba(10, 36, 45, 0.6)',
					fontSize: '.775rem',
				},
				'#insuredSportSelectionView-content-container-1, #insuredSportSelectionView-content-container-0': {
					textAlign: 'center',
					marginBottom: '2rem!important',
					marginTop: '.5rem!important',
					'@media (max-width: 660px)': {
						textAlign: 'left',
					}
				},
				'#policy-utility-singleSports-radio-button-wrapper': {
					alignItems: 'center',
					display: 'grid!important',
					margin: '0 2rem',
					gridTemplateColumns: 'repeat(4, 1fr)',
					gridGap: '1rem',
					'@media (max-width: 768px)': {
						gridTemplateColumns: 'repeat(3, 1fr)',
					},
					'@media (max-width: 600px)': {
						margin: '0 1rem 0 0',
					},
					'@media (max-width: 350px)': {
						gridTemplateColumns: 'repeat(2, 1fr)',
					},
				},
				'#policy-utility-singleSports-radio-button-wrapper input[type=radio] + label': {
					color: 'var(--color-primary)',
					fontWeight: 'bold',
					'@media (max-width: 768px)': {
						fontSize: '12px',
					},
				},
				'label[for=policy-utility-singleSports-baseball]::before, label[for=policy-utility-singleSports-basketball]::before, label[for=policy-utility-singleSports-cheer]::before, label[for=policy-utility-singleSports-football]::before, label[for=policy-utility-singleSports-gymnastics]::before, label[for=policy-utility-singleSports-soccer]::before, label[for=policy-utility-singleSports-softball]::before, label[for=policy-utility-singleSports-trackAndField]::before, label[for=policy-utility-singleSports-volleyball]::before, label[for=policy-utility-singleSports-waterSports]::before, label[for=policy-utility-singleSports-winterSports]::before, label[for=policy-utility-singleSports-otherSports]::before': {
					display: 'block',
					backgroundRepeat: 'no-repeat',
					backgroundSize: 'contain',
					backgroundPosition: 'center',
					content: "''",
					width: '75px',
					height: '75px',
					textAlign: 'center',
					marginLeft: 'auto',
					marginRight: 'auto',
					marginBottom: '4px',
				},
				'label[for=policy-utility-singleSports-baseball], label[for=policy-utility-singleSports-basketball], label[for=policy-utility-singleSports-cheer], label[for=policy-utility-singleSports-football], label[for=policy-utility-singleSports-gymnastics], label[for=policy-utility-singleSports-soccer], label[for=policy-utility-singleSports-softball], label[for=policy-utility-singleSports-trackAndField], label[for=policy-utility-singleSports-volleyball], label[for=policy-utility-singleSports-waterSports], label[for=policy-utility-singleSports-winterSports], label[for=policy-utility-singleSports-otherSports]': {
					textAlign: 'center',
				},
				'label[for=policy-utility-singleSports-baseball]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/fld/icon_baseball_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-baseball]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/fld/icon_baseball_on.png")'
				},
				'label[for=policy-utility-singleSports-basketball]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/fld/icon_basketball_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-basketball]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/fld/icon_basketball_on.png")'
				},
				'label[for=policy-utility-singleSports-cheer]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/fld/icon_cheer_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-cheer]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/fld/icon_cheer_on.png")'
				},
				'label[for=policy-utility-singleSports-football]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/fld/icon_football_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-football]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/fld/icon_football_on.png")'
				},
				'label[for=policy-utility-singleSports-gymnastics]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/fld/icon_gymnastics_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-gymnastics]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/fld/icon_gymnastics_on.png")'
				},
				'label[for=policy-utility-singleSports-soccer]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/fld/icon_soccer_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-soccer]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/fld/icon_soccer_on.png")'
				},
				'label[for=policy-utility-singleSports-softball]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/fld/icon_softball_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-softball]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/fld/icon_softball_on.png")'
				},
				'label[for=policy-utility-singleSports-trackAndField]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/fld/icon_trackfield_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-trackAndField]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/fld/icon_trackfield_on.png")'
				},
				'label[for=policy-utility-singleSports-volleyball]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/fld/icon_volleyball_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-volleyball]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/fld/icon_volleyball_on.png")'
				},
				'label[for=policy-utility-singleSports-waterSports]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/fld/icon_watersports_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-waterSports]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/fld/icon_watersports_on.png")'
				},
				'label[for=policy-utility-singleSports-winterSports]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/fld/wintersports_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-winterSports]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/fld/wintersports_on.png")'
				},
				'label[for=policy-utility-singleSports-otherSports]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/fld/icon_othersports_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-otherSports]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/fld/icon_othersports_on.png")'
				},
				'#policy-utility-singleSports-radio-button-wrapper .radio-button, label[for=policy-utility-singleSports]': {
					display: 'none'
				},
				'#policy-utility-singleSports-radio-button-wrapper .radio-button-option-wrapper': {
					display: 'flex',
					justifyContent: 'center',
					marginRight: '0',
				},
				'#insuredIndividualSportSelection-content-container-0, #insuredIndividualSportSelection-content-container-1': {
					textAlign: 'center',
					marginBottom: '2rem!important',
					'@media (max-width: 660px)': {
						textAlign: 'left',
					}
				},
				'#leagueInformation-content-container-0, #leagueInformation-content-container-2, #leagueInformation-content-container-3 > p': {
					textAlign: 'center',
					'@media (max-width: 660px)': {
						textAlign: 'left',
					}
				},
				'#insuredIndividualSportSelection-content-container-7, #insuredIndividualSportSelection-content-container-2, #insuredIndividualSportSelection-content-container-3, #insuredIndividualSportSelection-content-container-4, #insuredIndividualSportSelection-content-container-5, #insuredIndividualSportSelection-content-container-6, #leagueInformation-content-container-1, #leagueInformation-content-container-4, #leagueInformation-content-container-5, #leagueInformation-content-container-6': {
					margin: '0 auto',
					width: '70%',
					'@media (max-width: 660px)': {
						width: '100%',
					}
				},
				'#policyDatesView-view-container': {
					textAlign: 'center',
					alignItems: 'center',
					position: 'relative',
					'@media (max-width: 660px)': {
						textAlign: 'left',
					}
				},
				'#policy-seasonStartDate-field-container, #policy-seasonEndDate-field-container': {
					'@media (min-width: 860px)': {
						maxWidth: '30%',
						minWidth: '30%',
						display: 'inline-grid',
						marginRight: '1%'
					}
				},
				'#policyDatesView-content-container-0 > p,': {
					marginBottom: '0!important',
				},
				'#policyDatesView-content-container-2': {
					p: {
						fontSize: '0.8rem!important',
						marginBottom: '1rem!important',
						marginTop: '1rem!important'
					},
					'p:nth-child(1)': {
						marginBottom: '0rem!important',
						marginTop: '2rem!important'
					},
					'p:nth-child(2)': {
						marginBottom: '2rem!important',
						marginTop: '0rem!important',
						fontSize: '0.7rem!important',
						fontWeight: 'bold!important'
					}
				},
				'#leagueInformation-content-container-2': {
					margin: '0 auto',
					marginTop: '2rem',
					maxWidth: '90%',
					'@media (max-width: 660px)': {
						maxWidth: 'unset',
					}
				},
				'#quote-price-label-container, #quickOfferView-view-title, #policy-utility-mobilePhoneCheckBox-field-container > label': {
					display: 'none'
				},
				'#policy-utility-mobilePhoneCheckBox-checkbox-wrapper > label': {
					color: 'rgba(10, 36, 45, 0.6)',
					fontSize: '14px'
				},
				'#quickOfferView-content-container-2': {
					// backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/fld/quoteImg.png")',
					// backgroundRepeat: 'no-repeat',
					// backgroundSize: 'contain',
					// content: "''",
					width: '40%',
					display: 'inline-block',
					padding: '1.5rem',
					height: '130px',
					backgroundColor: 'var(--color-primary)',
					marginBottom: '2rem',
					'@media (max-width: 768px)': {
						width: '100%',
						height: '130px',
						justifyContent: 'center',
						alignItems: 'center',
						margin: 'auto 0.01rem'
					}
				},
				'#quickOfferView-content-container-2 h2': {
					textAlign: 'center',
					color: '#FFFFFF!important',
					fontSize: '50px!important',
					fontWeight: 'bold!important',
					fontFamily: 'Roboto, sans-serif',
					marginBottom: '0!important',
					opacity: 0,
					animation: 'fadeIn 0.5s ease 1.5s forwards', // 2s duration, 2s delay
					'@keyframes fadeIn': {
						from: { opacity: 0 },
						to: { opacity: 1 }
					},
					'@media (max-width: 768px)': {
						textAlign: 'center',
						color: '#FFFFFF!important',
						fontSize: '55px!important',
						fontWeight: 'bold!important'
					}
				},
				'#quickOfferView-content-container-2 p': {
					color: '#FFFFFF!important',
					textAlign: 'center',
					width: '100%',
					marginBottom: '0!important',
					fontSize: '12px!important',
					'@media (max-width: 768px)': {
						fontSize: '12px!important',
					},
					'@media (max-width: 410px)': {
						fontSize: '10px!important'
					},
				},
				'#quickOfferView-content-container-2 p:nth-child(2)': {
					fontWeight: 'bold!important'
				},
				'#quickOfferView-content-container-2 p:nth-child(2), #quickOfferView-content-container-2 p:nth-child(3)': {
					marginTop: '0!important'
				},
				'#quickOfferView-content-container-0 h2, #quickOfferView-content-container-1 h2': {
					marginTop: '50px',
					// marginLeft: '3rem',
					marginRight: '2rem',
					textAlign: 'left',
					lineHeight: '3rem!important',
					'@media (max-width: 768px)': {
						marginLeft: '0rem!important',
						marginRight: '0rem!important',
						// textAlign: 'center',
						fontSize: '30px!important',
						marginTop: '2rem'
					}
				},
				'#quickOfferView-view-container': {
					position: 'relative',
					textAlign: 'right',
					paddingLeft: '20px',
					'@media (max-width: 960px)': {
						textAlign: 'left',
						paddingLeft: '0'
					},
				},
				'#quickOfferView-content-container-1, #quickOfferView-content-container-0': {
					width: '60%',
					display: 'inline-block',
					'@media (max-width: 660px)': {
						width: '100%',
					},
				},
				'#customerInfoView-content-container-5 > p, #policyDatesView-content-container-6 > p, #policyDatesView-content-container-7 > p': {
					color: '#d62719!important'
				},
				'#customerInfoView-content-container-10 > p': {
					textAlign: 'center',
					marginTop: '4rem!important'
				},
				table: {
					borderCollapse: 'collapse',
					margin: '0 auto',
					marginBottom: '.5rem',
					padding: '.25rem',
					minWidth: '90%',
					width: '90%',
					tableLayout: 'inherit',
					fontColor: 'black',
					'@media (max-width: 600px)': {
						border: 0
					}
				},
				'#summary-content-container-2 > table > thead > tr > th:nth-child(2), #summary-content-container-4 > table > thead > tr > th:nth-child(2), #summary-content-container-6 > table > thead > tr > th:nth-child(2), #summary-content-container-8 > table > thead > tr > th:nth-child(2)': {
					'@media (max-width: 600px)': {
						display: 'flex',
						justifyContent: 'space-between',
						'font-size': '.8em'
					}

				},
				'#quickOfferView-content-container-3 > table > tbody > tr:nth-child(1) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Accident'",
						display: 'block',
						'font-size': '1.5em',
						color: 'var(--color-primary)'
					}
				},
				'#quickOfferView-content-container-3 > table > tbody > tr:nth-child(2) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Sickness'",
						display: 'block',
						'font-size': '1.5em',
						color: 'var(--color-primary)'
					}
				},
				'#quickOfferView-content-container-3 > table > tbody > tr:nth-child(3) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Accidental Death & Dismemberment'",
						display: 'block',
						'font-size': '1.5em',
						color: 'var(--color-primary)'
					}
				},
				'#quickOfferView-content-container-4 > table > tbody > tr:nth-child(1) > td:nth-child(2):before, #quickOfferView-content-container-5 > table > tbody > tr:nth-child(1) > td:nth-child(2):before, #quickOfferView-content-container-6 > table > tbody > tr:nth-child(1) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'24 Hour Accident'",
						display: 'block',
						'font-size': '1.5em',
						color: 'var(--color-primary)'
					}
				},
				'#quickOfferView-content-container-4 > table > tbody > tr:nth-child(2) > td:nth-child(2):before, #quickOfferView-content-container-6 > table > tbody > tr:nth-child(2) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'24 Hour Sickness'",
						display: 'block',
						'font-size': '1.5em',
						color: 'var(--color-primary)'
					}
				},
				'#quickOfferView-content-container-4 > table > tbody > tr:nth-child(3) > td:nth-child(2):before, #quickOfferView-content-container-5 > table > tbody > tr:nth-child(2) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'24 Hour Accidental Death & Dismemberment'",
						display: 'block',
						'font-size': '1.5em',
						color: 'var(--color-primary)'
					}
				},
				'#quickOfferView-content-container-3 > table > tbody > tr:nth-child(1) > td:nth-child(3):before, #quickOfferView-content-container-3 > table > tbody > tr:nth-child(2) > td:nth-child(3):before, #quickOfferView-content-container-3 > table > tbody > tr:nth-child(3) > td:nth-child(3):before': {
					'@media (max-width: 600px)': {
						content: "'Coverage Information'"
					}
				},
				'#quickOfferView-content-container-4 > table > tbody > tr:nth-child(1) > td:nth-child(3):before, #quickOfferView-content-container-4 > table > tbody > tr:nth-child(2) > td:nth-child(3):before, #quickOfferView-content-container-4 > table > tbody > tr:nth-child(3) > td:nth-child(3):before': {
					'@media (max-width: 600px)': {
						content: "'Coverage Information'"
					}
				},
				'#quickOfferView-content-container-5 > table > tbody > tr:nth-child(1) > td:nth-child(3):before, #quickOfferView-content-container-5 > table > tbody > tr:nth-child(2) > td:nth-child(3):before, #quickOfferView-content-container-5 > table > tbody > tr:nth-child(3) > td:nth-child(3):before': {
					'@media (max-width: 600px)': {
						content: "'Coverage Information'"
					}
				},
				'#quickOfferView-content-container-6 > table > tbody > tr:nth-child(1) > td:nth-child(3):before, #quickOfferView-content-container-6 > table > tbody > tr:nth-child(2) > td:nth-child(3):before, #quickOfferView-content-container-6 > table > tbody > tr:nth-child(3) > td:nth-child(3):before': {
					'@media (max-width: 600px)': {
						content: "'Coverage Information'"
					}
				},
				'#customerInfoView-content-container-0 > h2': {
					textAlign: 'center',
					marginBottom: '2rem',
					'@media (max-width: 660px)': {
						textAlign: 'left',
					}

				},
				'#insuranceReplacementView-view-container': {
					marginTop: '2rem!important',
				},
				'#summary-content-container-1,#summary-content-container-2, #summary-content-container-3, #summary-content-container-4, #summary-content-container-5, #summary-content-container-6, #summary-content-container-7, #summary-content-container-8': {
					table: {
						borderCollapse: 'collapse',
						margin: '0 auto',
						marginBottom: '.5rem',
						padding: '.25rem',
						minWidth: '90%',
						width: '90%',
						tableLayout: 'inherit',
						fontColor: 'black',
						'@media (max-width: 600px)': {
							border: 0,
							width: '100%'
						}
					},
					caption: {
						fontSize: '1.5em',
						margin: '.5em 0 .75em',
						'@media (max-width: 600px)': {
							border: 0
						}
					},
					'table tr': {
						backgroundColor: '#fff',
						border: '1px solid #ddd',
						'@media (max-width: 600px)': {
							display: 'block'
						}
					},
					'table th': {
						fontSize: '.95em',
						'@media (max-width: 600px)': {}
					},
					'table th, table td': {
						padding: '.625em',
						'@media (max-width: 600px)': {}
					},
					'table td': {
						'@media (max-width: 600px)': {
							borderBottom: '1px solid #ddd',
							display: 'block',
							fontSize: '.8em',
							textAlign: 'right',
							minHeight: '35px'
						}
					},
					'thead > tr > th:first-child': {
						'@media (max-width: 600px)': {
							display: 'none'
						}
					},
					'tbody > tr > td:first-child': {
						'@media (max-width: 600px)': {
							display: 'none'
						}
					},
					'table > tbody > tr > td:nth-child(2), thead > tr > th:nth-child(2)': {
						'@media (max-width: 600px)': { width: '100%!important' }
					},
					'tbody > tr > td:last-child': {
						'@media (max-width: 600px)': {
							paddingRight: '.5rem',
							textAlign: 'right'
						}
					},
					'td:before, th:before': {
						'@media (max-width: 600px)': {
							float: 'left',
							fontWeight: 'bold',
							textTransform: 'uppercase',
							paddingRight: '.5rem'
						}
					},
				},
				'#summary-content-container-1, #summary-content-container-3, #summary-content-container-5, #summary-content-container-7': {
					'thead > tr > th:first-child': {
						'@media (max-width: 600px)': {
							display: 'block'
						}
					},
				},
				'#quickOfferView-content-container-3, #quickOfferView-content-container-4, #quickOfferView-content-container-5, #quickOfferView-content-container-6': {
					table: {
						borderCollapse: 'collapse',
						margin: '0 auto',
						marginBottom: '.5rem',
						padding: '.25rem',
						minWidth: '90%',
						width: '90%',
						tableLayout: 'inherit',
						fontColor: 'black',
						'@media (max-width: 600px)': {
							border: 0,
							width: '100%'
						}
					},
					thead: {
						'@media (max-width: 600px)': {
							border: 'none',
							clip: 'rect(0 0 0 0)',
							height: '1px',
							margin: '-1px',
							overflow: 'hidden',
							padding: 0,
							position: 'absolute',
							width: '1px'
						}
					},
					caption: {
						fontSize: '1.5em',
						margin: '.5em 0 .75em',
						'@media (max-width: 600px)': {
							border: 0
						}
					},
					'table tr': {
						backgroundColor: '#fff',
						border: '1px solid #ddd',
						'@media (max-width: 600px)': {
							display: 'block'
						}
					},
					'table th': {
						fontSize: '.95em',
						'@media (max-width: 600px)': {}
					},
					'table th, table td': {
						padding: '.625em',
						// textAlign: 'center',
						'@media (max-width: 600px)': {}
					},
					'table td': {
						'@media (max-width: 600px)': {
							borderBottom: '1px solid #ddd',
							display: 'block',
							fontSize: '.8em',
							textAlign: 'left',
							minHeight: '35px'
						}
					},
					'thead > tr > th:first-child': {
						'@media (max-width: 600px)': {
							display: 'none'
						}
					},
					'tbody > tr > td:first-child': {
						'@media (max-width: 600px)': {
							display: 'none'
						}
					},
					'table > tbody > tr > td:nth-child(2), thead > tr > th:nth-child(2)': {
						'@media (max-width: 600px)': { width: '100%!important' }
					},
					'tbody > tr > td:last-child': {
						'@media (max-width: 600px)': {
							paddingRight: '.5rem',
							textAlign: 'left'
						}
					},
					'td:before, th:before': {
						'@media (max-width: 600px)': {
							display: 'block',
							fontWeight: 'bold',
							textTransform: 'uppercase',
							paddingRight: '.5rem'
						}
					},
				},
				'#summary-content-container-2 > table > thead > tr > th:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Name'"
					}
				},
				'#summary-content-container-2 > table > tbody > tr:nth-child(1) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'DOB'"
					}
				},
				'#summary-content-container-2 > table > tbody > tr:nth-child(2) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Policy Dates'"
					}
				},
				'#summary-content-container-2 > table > tbody > tr:nth-child(3) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Gender'"
					}
				},
				'#summary-content-container-2 > table > tbody > tr:nth-child(4) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Sport'"
					}
				},
				'#summary-content-container-2 > table > tbody > tr:nth-child(5) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'League/Team'"
					}
				},
				'#summary-content-container-4 > table > thead > tr > th:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'League/Team Name'"
					}
				},
				'#summary-content-container-4 > table > tbody > tr:nth-child(1) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Season Dates'"
					}
				},
				'#summary-content-container-4 > table > tbody > tr:nth-child(2) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Registration Fees'"
					}
				},
				'#summary-content-container-4 > table > tbody > tr:nth-child(3) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Premium'"
					}
				},
				'#summary-content-container-6 > table > thead > tr > th:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Name'"
					}
				},
				'#summary-content-container-6 > table > tbody > tr:nth-child(1) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Address'"
					}
				},
				'#summary-content-container-6 > table > tbody > tr:nth-child(2) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Mobile Number'"
					}
				},
				'#summary-content-container-6 > table > tbody > tr:nth-child(3) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Email'"
					}
				},
				'#summary-content-container-8 > table > thead > tr > th:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Name'"
					}
				},
				'#summary-content-container-8 > table > tbody > tr:nth-child(1) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Address'"
					}
				},
				'#quickOfferView-content-container-3 > table > thead > tr > th, #quickOfferView-content-container-4 > table > thead > tr > th, #quickOfferView-content-container-5 > table > thead > tr > th, #quickOfferView-content-container-6 > table > thead > tr > th': {
					backgroundColor: 'var(--color-primary)',
					color: '#FFF'
				},
				'#quickOfferView-content-container-3 > table, #quickOfferView-content-container-4 > table, #quickOfferView-content-container-5 > table, #quickOfferView-content-container-6 > table': {
					maxWidth: 'none!important'
				},
				'#quickOfferView-content-container-3 > table > thead > tr > th > nth-child(1), #quickOfferView-content-container-4 > table > thead > tr > th > nth-child(1), #quickOfferView-content-container-5 > table > thead > tr > th > nth-child(1), #quickOfferView-content-container-6 > table > thead > tr > th > nth-child(1)': {
					paddingLeft: '0px!important'
				},
				'#summary-content-container-1 > table > thead > tr > th, #summary-content-container-3 > table > thead > tr > th, #summary-content-container-5 > table > thead > tr > th, #summary-content-container-7 > table > thead > tr > th': {
					fontWeight: 'bold',
					color: '#FFF!important',
					paddingBottom: '1rem!important'
				},
				'#summary-content-container-1 > table > thead > tr, #summary-content-container-3 > table > thead > tr > th, #summary-content-container-5 > table > thead > tr > th, #summary-content-container-7 > table > thead > tr > th': {
					backgroundColor: 'var(--color-primary)',
					color: '#FFF'
				},
				'#summary-content-container-0 > table > tbody > tr > td, #summary-content-container-2 > table > thead > tr > th, #summary-content-container-4 > table > thead > tr > th, #summary-content-container-2 > table > tbody > tr > td, #summary-content-container-4 > table > thead > tr > th, #summary-content-container-4 > table > tbody > tr > td, #summary-content-container-6 > table > thead > tr > th, #summary-content-container-6 > table > tbody > tr > td, #summary-content-container-8 > table > thead > tr > th, #summary-content-container-8 > table > tbody > tr > td': {
					fontWeight: '400',
					textAlign: 'left',
					paddingTop: '.6rem',
					paddingBottom: '.6rem',
					backgroundColor: '#FFF!important',
					width: '50%'
				},
				'#summary-content-container-2 > table > thead > tr > th, #summary-content-container-4 > table > thead > tr > th, #summary-content-container-6 > table > thead > tr > th, #summary-content-container-2 > table > tbody > tr > td, #summary-content-container-4 > table > tbody > tr > td, #summary-content-container-6 > table > tbody > tr > td, #summary-content-container-8 > table > tbody > tr > td, #summary-content-container-8 > table > thead > tr > th': {
					color: '#333333!important'
				},
				'#summary-content-container-2 > table > tbody > tr > td, #summary-content-container-2 > table > thead > tr > th, #summary-content-container-4 > table > tbody > tr:nth-child(1) > td:nth-child(2) > a, #summary-content-container-6 > table > thead > tr > th, #summary-content-container-8 > table > thead > tr > th': {
					fontWeight: '400!important',
					backgroundColor: '#FFF!important'
				},
				'#summary-content-container-2, #summary-content-container-4, #summary-content-container-6, #summary-content-container-8': {
					marginTop: '-20px'
				},
				'#policy-electronicSignature-field-container .input-error, #policy-utility-electronicDisclosure-field-container .input-error, #policy-utility-electronicSignature-field-container > label, #policy-utility-electronicDisclosure-field-container > label': {
					display: 'none'
				},
				'.input-error': {
					marginTop: '0rem!important',
				},
				'#policy-utility-manuallyEnterAddress-checkbox-wrapper': {
					marginBottom: '1rem!important'
				},
				'#summary-content-container-2 > table > tbody > tr:nth-child(1), #summary-content-container-2 > table > tbody > tr:nth-child(3), #summary-content-container-4 > table > tbody > tr:nth-child(1), #summary-content-container-4 > table > tbody > tr:nth-child(3), #summary-content-container-6 > table > tbody > tr:nth-child(1), #summary-content-container-8 > table > tbody > tr:nth-child(1)': {
					backgroundColor: '#FFF!important'
				},
				'#summary-content-container-0 > h3': {
					fontWeight: 'normal'
				},
				'#checkout-content-container-2': {
					right: '0',
					width: '100px',
					height: '100px',
					position: 'absolute',
					bottom: '60%',
					'@media (max-width: 768px)': {
						display: 'none'
					}
				},
				'#checkout-content-container-1 h2': {
					lineHeight: '2.25rem!important'
				},
				'#checkout-view-container': {
					minHeight: '150px !important',
					display: 'flex',
					flexDirection: 'column',
					justifyContent: 'center',
					alignItems: 'center',
					textAlign: 'center',
					marginLeft: '10%',
					marginRight: '10%',
					'@media (max-width: 601px)': {
						marginLeft: '0',
						marginRight: '0'
					}
				},
				'#checkout-view-title': {
					display: 'none'
				},
				'#thanks-view-container, #quote-error-view-view-container, #knockoutStateView-view-container, #insuranceReplacementView-view-container, #knockoutComplianceInDcView-view-container': {
					display: 'flex',
					flexDirection: 'column',
					justifyContent: 'center',
					alignItems: 'center',
					textAlign: 'center',
					color: '#333333!important',
					lineHeight: '1',
					'@media (max-width: 660px)': {
						display: 'block',
						textAlign: 'left!important'
					}
				},
				'#thanks-view-container': {
					marginTop: '60px!important',
					'@media (max-width: 660px)': {
						marginTop: '40px!important',
					}
				},
				'#insuranceReplacementView-content-container-2::after': {
					content: '""',
					display: 'block',
					// width: '300px',
					// height: '300px',
					margin: '0 auto',
				},
				'#knockoutStateView-content-container-2::after': {
					content: '""',
					display: 'block',
					// width: '300px',
					// height: '300px',
					margin: '0 auto',
				},
				'#knockoutStateView-content-container-0 h2, #quote-error-view-content-container-0 h2, #insuranceReplacementView-content-container-0 h2': {
					fontSize: '50px!important'
				},
				'#knockoutStateView-content-container-1 p, #insuranceReplacementView-content-container-1 p': {
					marginBottom: '0'
				},
				'#knockoutStateView-content-container-1 > p, #knockoutStateView-content-container-2 > p, #insuranceReplacementView-content-container-1 p, #insuranceReplacementView-content-container-2 p, #quote-error-view-content-container-1 p, #quote-error-view-content-container-2 p, #quote-error-view-content-container-3 p, #quote-error-view-content-container-4 p': {
					color: '#333333!important',
					marginTop: '0px!important',
					marginBottom: '1px!important'
				},
				'#thanks-content-container-0::after': {
					content: '""',
					display: 'block',
					// background: 'url("https://staging.embed.buddy.insure/gaig/fld/coachCelebration.png") no-repeat center',
					// backgroundSize: 'contain',
					width: '300px',
					height: '40px',
					marginLeft: '112px'
				},
				'#thanks-content-container-1 > p, #thanks-content-container-2 > p, #thanks-content-container-3 > p, #quote-error-view-content-container-1 > h3': {
					color: '#333333!important',
					marginTop: '0px!important',
					marginBottom: '1px!important'
				},
				'.button-primary': {
					textTransform: 'uppercase',
					transition: 'border-color .4s ease 0s,background-color .4s ease 0s',
					border: '2px solid var(--color-secondary)',
					borderRadius: '0rem !important',
					background: 'var(--color-secondary)',
					padding: '.75rem 1.125rem',
					fontWeight: 'bold',
					fontFamily: 'Roboto, sans-serif',
					fontSize: '13px',
					height: '40px',
					color: '#FFFFFF',
					marginTop: '2rem',
					bottom: '0',
					'&:hover': {
						background: '#FFFFFF',
						color: 'var(--color-primary)'
					},
					'@media (min-width: 768px)': {
						minWidth: 'unset'
					}
				},
				'.button-secondary': {
					textTransform: 'uppercase',
					transition: 'border-color .4s ease 0s,background-color .4s ease 0s',
					border: '2px solid var(--color-secondary)',
					borderRadius: '0rem !important',
					background: 'var(--color-secondary)',
					padding: '.75rem 1.125rem',
					fontWeight: 'bold',
					fontFamily: 'Roboto, sans-serif',
					fontSize: '13px',
					lineHeight: '0px!important',
					marginTop: '2rem!important',
					height: '40px',
					textAlign: 'center',
					color: '#FFFFFF',
					'&:hover': {
						background: '#FFFFFF',
						color: 'var(--color-primary)'
					},
					'@media (min-width: 768px)': {
						minWidth: 'unset'
					}
				},
				button: {
					textTransform: 'uppercase',
					backgroundColor: '#f3f6f9',
					fontWeight: 'bold',
					fontSize: '16px',
					lineHeight: '1',
					padding: '.75rem 1.125rem',
					color: '#fff',
					transition: 'background-color .4s ease 0s',
					borderRadius: '0rem'
				},
				body: {
					fontFamily: 'Roboto, sans-serif',
					fontSize: '16px',
					'@media (min-width: 768px)': {
						fontSize: '16px'
					},
					margin: '0 auto'
				},
				h2: {
					fontFamily: 'Roboto, sans-serif',
					fontWeight: '400!important',
					marginTop: '2rem',
					fontSize: '50px',
					color: 'var(--color-primary)!important',
					'@media (max-width: 768px)': {
						fontSize: '35px!important'
					},
					'@media (max-width: 450px)': {
						fontSize: '30px!important'
					}
				},
				h3: {
					fontFamily: 'Roboto, sans-serif',
					fontWeight: 'bold',
					fontSize: '30px',
					color: 'var(--color-primary)'
				}
			},
			colors: {
				primary: '#9C1C31',
				secondary: '#5aa3f2',
				textPrimary: '#333333',
			},
			webFonts: [
				'https://fonts.googleapis.com/css2?family=Roboto&display=swap'
			]
		}
	},
};
